package VMOMI::BatchResultResult;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
